aboutsummaryrefslogtreecommitdiff
path: root/src/modules/commander/accelerometer_calibration.c
diff options
context:
space:
mode:
authorLorenz Meier <lm@inf.ethz.ch>2013-07-21 11:29:10 +0200
committerLorenz Meier <lm@inf.ethz.ch>2013-07-21 11:29:10 +0200
commitdc5bcdda761e5f8f4f7f26a600f02df007ab1df6 (patch)
tree0521c5844569c7c12882840335560bb1ae1992d8 /src/modules/commander/accelerometer_calibration.c
parent0f19de53119e5d89b2520f6906ab50fc9d3a3b28 (diff)
downloadpx4-firmware-dc5bcdda761e5f8f4f7f26a600f02df007ab1df6.tar.gz
px4-firmware-dc5bcdda761e5f8f4f7f26a600f02df007ab1df6.tar.bz2
px4-firmware-dc5bcdda761e5f8f4f7f26a600f02df007ab1df6.zip
Hotfix: Made accel calibration a bit more forgiving about motion threshold
Diffstat (limited to 'src/modules/commander/accelerometer_calibration.c')
-rw-r--r--src/modules/commander/accelerometer_calibration.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/modules/commander/accelerometer_calibration.c b/src/modules/commander/accelerometer_calibration.c
index dc653a079..6a304896a 100644
--- a/src/modules/commander/accelerometer_calibration.c
+++ b/src/modules/commander/accelerometer_calibration.c
@@ -268,8 +268,8 @@ int detect_orientation(int mavlink_fd, int sub_sensor_combined) {
float accel_disp[3] = { 0.0f, 0.0f, 0.0f };
/* EMA time constant in seconds*/
float ema_len = 0.2f;
- /* set "still" threshold to 0.1 m/s^2 */
- float still_thr2 = pow(0.1f, 2);
+ /* set "still" threshold to 0.25 m/s^2 */
+ float still_thr2 = pow(0.25f, 2);
/* set accel error threshold to 5m/s^2 */
float accel_err_thr = 5.0f;
/* still time required in us */